@@ -81,7 +81,11 @@ class light_curve(observation):
         self._exposure_ = ff[data_ind].header['EXPOSURE']
 
         #TODO Use this value
-        self._timepixr_ = ff[data_ind].header['TIMEPIXR']
+        try:
+            self._timepixr_ = ff[data_ind].header['TIMEPIXR']
+        except:
+            logger.warning('Not found TIMEPIXR, defaulting to zero')
+            self._timepixr_ = 0
 
         self._timedel_ = ff[data_ind].header['TIMEDEL']
 
